| get_profile | R Documentation |
Implement the sedentary profiles
get_profile(object, ...)
## S3 method for class 'bout'
get_profile(object, method = c("both", "decisionTree", "randomForest"), ...)
## S3 method for class 'data.frame'
get_profile(
object,
method = c("both", "decisionTree", "randomForest"),
id = NULL,
counts = NULL,
wear = NULL,
sb = 100,
valid_indices = NULL,
...
)
## S3 method for class 'list'
get_profile(object, method = c("both", "decisionTree", "randomForest"), ...)
object |
input (either data frame or output from
|
... |
further arguments passed to |
method |
character. The model(s) to use for the prediction |
id |
character scalar (optional). Column name on which to divide
|
counts |
character scalar. Column name of the variable to use when classifying sedentary behavior (and wear time, depending on the function) |
wear |
character scalar [optional]. Column name of the variable to use
for determining wear time (logical vector with |
sb |
integer. The cut point to use for classifying sedentary behavior |
valid_indices |
integer vector (optional) specifying which indices of
|
one or more profile assignments
data(example_data, package = "SBprofiles") get_profile(example_data, counts = "PAXINTEN") get_profile( example_data, counts = "PAXINTEN", method = "randomForest" ) get_profile(example_data, id = "PAXDAY", counts = "PAXINTEN") get_profile( example_data, id = "PAXDAY", counts = "PAXINTEN", method = "decisionTree" )
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.